Address class

Represents an address within a specific account and subaddress index.

In Monero (or Wownero), each account can have multiple subaddresses, and each subaddress is identified by an index. This class encapsulates the information necessary to identify a unique Monero (or Wownero) address.

Constructors

Address({required String value, required int account, required int index})
Creates an Address with the given Monero (or Wownero) value, account index, and index within the account. NOTE: No validation beyond negative account or index values occurs here!

Properties

account int
The account index in the Monero (or Wownero) wallet where this address is located.
final
hashCode int
The hash code for this object.
no setterinherited
index int
The subaddress index within the specified account.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The actual Monero (or Wownero) address string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited