CSPrefixPrinter class

Constructors

CSPrefixPrinter(LogPrinter _realPrinter, {String? debug, String? trace, String? fatal, String? info, String? warning, String? error})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() Future<void>
inherited
init() Future<void>
inherited
log(LogEvent event) List<String>
Is called every time a new LogEvent is sent and handles printing or storing the message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited