PendingTransaction class

Holds the pointer address of a pending transaction in the native code as well as some associated data exposed to Dart.

Constructors

PendingTransaction({required BigInt amount, required BigInt fee, required String txid, required String hex, required int pointerAddress})

Properties

amount BigInt
The amount in atomic units being transferred in this transaction. Does not include the fee.
final
fee BigInt
The transaction fee in atomic units.
final
hashCode int
The hash code for this object.
no setterinherited
hex String
The raw transaction data in hexadecimal format.
final
pointerAddress int
The address of the pointer to the underlying pending transaction object.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txid String
The transaction Id (or hash).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited