Recipient class

Represents a recipient in a transaction, including their address and the amount to be transferred.

Constructors

Recipient({required String address, required BigInt amount})
Creates a Recipient with the given address and amount.

Properties

address String
The address of the recipient where the funds will be sent.
final
amount BigInt
The amount of funds to be transferred to the recipient, represented in atomic units.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited