TransactionPriority enum

Inheritance
Available extensions

Values

normal → const TransactionPriority
const TransactionPriority(0)
low → const TransactionPriority
const TransactionPriority(1)
medium → const TransactionPriority
const TransactionPriority(2)
high → const TransactionPriority
const TransactionPriority(3)
last → const TransactionPriority
const TransactionPriority(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TransactionPriority>
A constant List of the values in this enum, in order of their declaration.