cs_monero library
Support for doing something awesome.
More dartdocs go here.
Classes
- Address
- Represents an address within a specific account and subaddress index.
- CSPrefixPrinter
- Logging
- A singleton logging instance that provides some debug info. Disabled by default.
- MoneroWallet
- Output
- Represents a Monero transaction output.
- PendingTransaction
- Holds the pointer address of a pending transaction in the native code as well as some associated data exposed to Dart.
- Recipient
- Represents a recipient in a transaction, including their address and the amount to be transferred.
- Transaction
- Represents a Monero (or Wownero) transaction for a given wallet.
- Wallet
- WalletListener
- A listener class for wallet-related events during synchronization/continuous polling.
Functions
-
getMoneroWordList(
String language) → List< String>