Logging class abstract
A singleton logging instance that provides some debug info. Disabled by default.
Usage
To enable logging, set useLogger to true. This initializes a default Logger
instance using a PrefixPrinter for prefixed logs and a PrettyPrinter for
formatted output.
Custom Logger
Constructors
- Logging()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited