Output class
Represents a Monero transaction output.
In Monero (or Wownero), an output is a part of a transaction that can be used as input in subsequent transactions. This class encapsulates information about the specific output, including its address, hash, value, and more.
Constructors
- Output({required String address, required String hash, required String keyImage, required BigInt value, required bool isFrozen, required bool isUnlocked, required int height, required int? spentHeight, required int vout, required bool spent, required bool coinbase})
-
Creates an Output with the specified Monero transaction details. NOTE:
No validation of any properties (besides a negative
valueorvout, and a non emptykeyImage) occurs here.
Properties
- address → String
-
The receiving Monero address.
final
- coinbase → bool
-
Whether this output originates from a coinbase transaction.
final
- hash → String
-
The hash of the transaction in which this output was created.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
The blockchain height where this output was created.
final
- isFrozen → bool
-
Whether this output is frozen, preventing it from being spent.
final
- isUnlocked → bool
-
Whether this output is unlocked and available for spending.
final
- keyImage → String
-
A unique identifier for this output.
See https://monero.stackexchange.com/questions/2883/what-is-a-key-image
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spent → bool
-
Whether this output has already been spent.
final
- spentHeight → int?
-
The blockchain height where this output was spent, or
nullif unspent.final - value → BigInt
-
The value of the output, in atomic units.
final
- vout → int
-
The output index within the transaction.
final
Methods
-
copyWithFrozen(
bool isFrozen) → Output -
Returns a copy of this Output instance, with the
isFrozenstatus updated. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromRawMap(
Map< String, dynamic> map) → Output